#!/bin/sh
#
# rc.M		This file is executed by init(8) when the system is being
#		initialized for one of the "multi user" run levels (i.e.
#		levels 1 through 6).  It usually does mounting of file
#		systems et al.

. /etc/config.data/kernel

# Tell the viewers what's going to happen...
echo "Going multiuser..."

# Check if system has been configured
if [ -f /etc/.notconfigured ]; then
    configure
    echo "System should now be rebooted (if you have configured it, that is)"
    echo ""
    echo -n "Do you want to reboot ? ([y]/n): "
    read
    if [ ${REPLY:-y} = "y" ]; then
	echo "Remounting the disk read-only and reboot..."
	remount r
        reboot
    fi
    echo ""
    echo "Your system will now continue to boot..."
    echo ""
fi

# Set the hostname.
hostname `cat /etc/HOSTNAME`

# Set reboot time for panic to 1 minute
echo 60 > /proc/sys/kernel/panic

# Set buffer sizes, not used as of 2000-11-28
#echo '256 512 2048' > /proc/sys/vm/freepages

if [ `grep -c PCWD /proc/ioports` = 1 ] ; then
# Start the hardware watchdog (PCWD)
    if [ -f /sbin/watchdog ] ; then
       echo "PCWD Hardware Watchdog"
       watchdog &
    fi
else
# Start the software watchdog
    if [ -f /sbin/voff ] ; then
	echo "Voff - Software Watchdog"
	voff &
    fi
fi

# Check kernel module dependencies
depmod

# Detect hardware and modprobe appropriate kernel modules
# module may be disable in /etc/config.flags/MODULENAME.mod
for d in $(/usr/bin/eth-detect) NONE; do
    if [ -f /etc/config.flags/$d.mod ]; then
	if [ `cat /etc/config.flags/$d.mod` = no ]; then
	    echo "/etc/config.flags/$d.mod disabled"
	    continue
	fi
    fi
    [ "$d" = NONE ] || modprobe $d
done

# - - - - - - - - - - - - - - - - - - - - - -
# Initialize the NET subsystem.
if [ -f /etc/rc.d/rc.inet ]; then
    /etc/rc.d/rc.inet 2> /dev/null
fi

# Update all the shared library links automatically
ldconfig 2> /dev/null

# Sleep 4 seconds and then remount the flash disk read-only
sleep 4
remount r

# Start syslog
if [ -f /etc/rc.d/rc.syslog ]; then
    /etc/rc.d/rc.syslog
fi

# Kernel log daemon
if [ -f /usr/sbin/klogd ]; then
    echo " klogd"
    klogd -c 4
fi

# Zebra routing daemon + OSPFd and BGPd
export CONFIG_ZEBRA=`cat /etc/config.flags/zebra`
if [ $CONFIG_ZEBRA = "yes" ]; then
    PATH=$PATH:/opt/zebra/bin:/opt/zebra/sbin
    if [ -f /opt/zebra/rc.d/rc.zebra ]; then
	/opt/zebra/rc.d/rc.zebra
    fi
fi

# GateD routing daemon
export CONFIG_GATED=`cat /etc/config.flags/gated`
if [ $CONFIG_GATED = "yes" ]; then
    PATH=$PATH:/opt/gated/sbin
    if [ -f /opt/gated/rc.d/rc.gated ]; then
	/opt/gated/rc.d/rc.gated
    fi
fi

#_# #-- the rc script called have been empty for ... ever...	(emilp,20090310)
#_# # Set ICMP rate limit
#_# export CONFIG_ICMP_RATE=`cat /etc/config.flags/icmp-rate-limit`
#_# if [ $CONFIG_ICMP_RATE = "yes" ]; then
#_#     if [ -f /etc/rc.d/rc.rate-icmp ] ; then
#_# 	    echo "Setting up ICMP rate limit"
#_# 	    /etc/rc.d/rc.rate-icmp
#_#     fi
#_# fi

#_# #_# #-- the rc script called have been empty for ... ever...	(emilp,20090310)
#_# # Run the QoS script - special application hack for "Lagom"
#_# export CONFIG_QOS=`cat /etc/config.flags/qos-test`
#_# if [ $CONFIG_QOS = "yes" ]; then
#_#     if [ -f /etc/rc.d/rc.tc ] ; then
#_# 	    echo "Setting up QoS"
#_# 	    /etc/rc.d/rc.tc
#_#     fi
#_# fi

# Inetd daemon
export CONFIG_INETD=`cat /etc/config.flags/inetd`
if [ $CONFIG_INETD = "yes" ]; then
    if [ -f /usr/sbin/inetd ]; then
	echo -n " inetd"
	inetd
    fi
fi

# SSH daemon, needs full path to exec
export CONFIG_SSH=`cat /etc/config.flags/sshd`
if [ $CONFIG_SSH = "yes" ]; then
    if [ -f /usr/sbin/sshd ] ; then
	echo " sshd"
	/usr/sbin/sshd
#	/usr/sbin/sshd -u 0
    fi
fi

# Vixie Cron
export CONFIG_CRON=`cat /etc/config.flags/cron`
if [ $CONFIG_CRON = "yes" ]; then
    if [ -f /usr/sbin/cron ] ; then
	echo " cron"
	cron
    fi
fi

# SNMP daemon
export CONFIG_SNMP=`cat /etc/config.flags/snmpd`
if [ $CONFIG_SNMP = "yes" ]; then
    if [ -f /opt/snmp/rc.d/rc.snmp ] ; then
	PATH=$PATH:/opt/snmp/bin:/opt/snmp/sbin
	/opt/snmp/rc.d/rc.snmp
    fi
fi

# Start the Apache+OpenSSL server for Bifrost Nomad
export CONFIG_HTTP=`cat /etc/config.flags/http`
if [ $CONFIG_HTTP = "yes" ]; then
    if [ -f /opt/www/rc.d/rc.http ] ; then
	PATH=$PATH:/opt/www/apache/bin
	/opt/www/rc.d/rc.http start
    fi
fi

# Load the exec logging module
export CONFIG_EXECLOG=`cat /etc/config.flags/execlog`
if [ $CONFIG_EXECLOG = "yes" ]; then
    if [ -f /etc/rc.d/rc.execlog ]; then
	/etc/rc.d/rc.execlog
    fi
fi

# Start the interface statistics daemon ifstat2
export CONFIG_IFSTAT2=`cat /etc/config.flags/ifstat2`
if [ $CONFIG_IFSTAT2 = "yes" ]; then
    if [ -f /sbin/ifstat2 ]; then
	/sbin/ifstat2 -d1 -t 5 > /dev/null
    fi
fi

# Start the DHCP server
export CONFIG_DHCP=`cat /etc/config.flags/dhcpd`
if [ $CONFIG_DHCP = "yes" ]; then
    if [ -f /etc/rc.d/rc.dhcp ]; then
	/etc/rc.d/rc.dhcp
    fi
fi

# Start the dnsmasq server
export CONFIG_DNSMASQ=`cat /etc/config.flags/dnsmasq`
if [ $CONFIG_DNSMASQ = "yes" ]; then
    if [ -f /usr/sbin/dnsmasq ]; then
        /usr/sbin/dnsmasq
    fi
fi

# Start the NTP server/client
export CONFIG_NTP=`cat /etc/config.flags/ntp`
if [ $CONFIG_NTP = "yes" ]; then
    if [ -f /etc/rc.d/rc.ntp ]; then
	/etc/rc.d/rc.ntp &
    fi
fi

# Start the Argus logger
export CONFIG_ARGUS=`cat /etc/config.flags/argus`
if [ $CONFIG_ARGUS = "yes" ]; then
    if [ -f /opt/sniff/rc.d/rc.argus ]; then
	PATH=$PATH:/opt/sniff/bin
	/opt/sniff/rc.d/rc.argus
    fi
fi

# Start the Snort logger
export CONFIG_SNORT=`cat /etc/config.flags/snort`
if [ $CONFIG_SNORT = "yes" ]; then
    if [ -f /opt/sniff/rc.d/rc.snort ]; then
	PATH=$PATH:/opt/sniff/bin
	/opt/sniff/rc.d/rc.snort
    fi
fi


#-- loop through all rc-scripts provided by extra optional packages
#-- for each of them check for matching config.flag -eq "yes" and
#-- if so run the rc-script with argument "start".
#--   Note that the rc-script should be fully self sustained with
#-- regards to paths and stuff.                 (emilp, 2003-10-01)

for file in $(ls /opt/*/etc/config.flags/* 2>/dev/null); do
    dir=${file%%/etc/*}
    pkg=${file##*/}
    if [ $(cat $file) = "yes" ]; then
        if [ -d $dir/bin ]; then PATH=$PATH:$dir/bin; fi
        if [ -d $dir/sbin ]; then PATH=$PATH:$dir/sbin; fi
        if [ -f "$dir/rc.d/rc.$pkg" ]; then
            $dir/rc.d/rc.$pkg start
        fi
    fi
done

