#!/bin/sh
#
# /etc/rc.d/rc.S:  System initialization script.

echo "?"

PATH=/bin:/sbin:/usr/bin:/usr/sbin:/etc

# mount /proc early to allow handling of LABEL.
mount /proc

# Check the integrity of all filesystems (add your own extras here)
e2fsck -p LABEL=bifrost

# If there was a failure, drop into single-user mode.
rc=$?
if [ $rc -gt 1 ] ; then
    echo
    echo
    echo "*****************************************"
    echo "fsck returned exit code $rc"
    echo "Common exit codes are: "
    echo "1 - File system errors corrected"
    echo "2 - File system errors corrected, system should be rebooted"
    echo "4 - File system errors left uncorrected"
    echo "*****************************************"
    echo
    echo
    echo "*****************************************"
    echo "Launching a minimal single user shell."
    echo "If you do not login normal boot will continue in 60 seconds"
    echo "*****************************************"
    echo
    echo
    login
fi

# Remount the root filesystem in read-write mode
echo "Remounting root device with read-write enabled."
#remount w
mount -n -w -o remount /

# Create /tmp, /proc and /sys
rm -rf /tmp
rm -rf /sys
mkdir -p /tmp /sys
chgrp tmp /tmp
chmod 1777 /tmp

# Remove /etc/mtab* so that mount will create it with a root entry
rm -f /etc/mtab*

# Create pseudo file systems
export TMPSIZE=`cat /etc/config.data/tmpsize`
mount -t tmpfs -o size=$TMPSIZE tmpfs /tmp
mount -t tmpfs tmpfs /dev

# Copy devices to tmpfs-dev
cp -ra /dev.real/* /dev

# if /var is _not_ the default ram disk, we need to mount it now
grep -q /var /etc/fstab && mount /var

# if /var is on kept between runs, we need to clean up old pids
[ -d /var/run ] && rm -f /var/run/*.pid

# Create directories as needed
echo "Adding files and directories to /var (usually /var -> /tmp)"
for d in adm spool spool/locks tmp log run empty; do
    [ -d /var/$d ] || mkdir -p /var/$d
done

# Mount file systems in fstab (and create an entry for /)
# but not NFS.
mount -avt nonfs

#Setup RAM logging
export RAM_LOG=`cat /etc/config.flags/ramlog`
if [ $RAM_LOG = "yes" ]; then
        cp -rp /usr/log.persistent/* /var/log/
fi

umask 077
touch /var/known_hosts_root /var/known_hosts2_root /var/log/lastlog /var/log/wtmp
umask 022
chgrp tmp /tmp
chmod 1777 /var/run

# SSH privsep.
chown root:sys /var/empty
chmod 0700 /var/empty

# Looks like we have to create this.
cat /dev/null > /var/run/utmp

# Prepare kernel module path
touch /etc/config.data/kernel
cp /dev/null /etc/config.data/kernel
echo "export KERNEL=`uname -r`" >> /etc/config.data/kernel

# Setup keyboard for slow typists
export CONFIG_SLOWKEYBOARD=`cat /etc/config.flags/slow-keyboard`
if [ $CONFIG_SLOWKEYBOARD = "yes" ]; then
    kbdrate -r 10.0 -d 700
fi

# Setup Swedish keyboard layout
echo "Setting Swedish keyboard layout..."
export CONFIG_SWKEYBOARD=`cat /etc/config.flags/swedish-keyboard`
if [ $CONFIG_SWKEYBOARD = "yes" ]; then
    loadkeys /etc/swedish.keyboard.map
fi
